@@ -1,36 +1,40 @@
 #' @title GLM with Elastic Net Regularization Classification Learner
 #'
-#' @usage NULL
 #' @name mlr_learners_classif.glmnet
-#' @format [R6::R6Class()] inheriting from [mlr3::LearnerClassif].
-#'
-#' @section Construction:
-#' ```
-#' LearnerClassifGlmnet$new()
-#' mlr3::mlr_learners$get("classif.glmnet")
-#' mlr3::lrn("classif.glmnet")
-#' ```
 #'
 #' @description
 #' Generalized linear models with elastic net regularization.
-#' Calls [glmnet::cv.glmnet()] from package \CRANpkg{glmnet}.
+#' Calls [glmnet::glmnet()] from package \CRANpkg{glmnet}.
+#'
+#' Caution: This learner is different to `_glmnet` in that it does not use the
+#' internal optimization of lambda. The parameter needs to be tuned by the user.
+#' Essentially, one needs to tune parameter `s` which is used at predict-time.
+#'
+#' See https://stackoverflow.com/questions/50995525/ for more information.
+#'
+#' @templateVar id classif.glmnet
+#' @template section_dictionary_learner
 #'
 #' @references
 #' \cite{mlr3learners}{friedman_2010}
 #'
 #' @export
 #' @template seealso_learner
-#' @templateVar learner_name classif.glmnet
 #' @template example
-LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet", inherit = LearnerClassif,
+LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet",
+  inherit = LearnerClassif,
+
   public = list(
+
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       ps = ParamSet$new(list(
         ParamDbl$new("alpha", default = 1, lower = 0, upper = 1, tags = "train"),
-        ParamInt$new("nfolds", default = 10L, lower = 3L, tags = "train"),
-        ParamFct$new("type.measure", levels = c("deviance", "class", "auc", "mse", "mae"), default = "deviance", tags = "train"),
-        ParamDbl$new("s", lower = 0, special_vals = list("lambda.1se", "lambda.min"), default = "lambda.1se", tags = "predict"),
-        ParamInt$new("nlambda", default = 100L, lower = 1L, tags = "train"),
+        ParamFct$new("type.measure",
+          levels = c("deviance", "class", "auc", "mse", "mae"),
+          default = "deviance", tags = "train"),
+        ParamDbl$new("s", lower = 0, default = 0.01, tags = "predict"),
         ParamDbl$new("lambda.min.ratio", lower = 0, upper = 1, tags = "train"),
         ParamUty$new("lambda", tags = "train"),
         ParamLgl$new("standardize", default = TRUE, tags = "train"),
@@ -43,9 +47,20 @@ LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet", inherit = LearnerClassif,
         ParamUty$new("lower.limits", tags = "train"),
         ParamUty$new("upper.limits", tags = "train"),
         ParamInt$new("maxit", default = 100000L, lower = 1L, tags = "train"),
-        ParamFct$new("type.logistic", levels = c("Newton", "modified.Newton"), tags = "train"),
-        ParamFct$new("type.multinomial", levels = c("ungrouped", "grouped"), tags = "train"),
-        ParamUty$new("gamma", tags = "train"),
+        ParamFct$new("type.logistic",
+          levels = c("Newton", "modified.Newton"),
+          tags = "train"),
+        ParamFct$new("type.multinomial",
+          levels = c("ungrouped", "grouped"),
+          tags = "train"),
+        ParamLgl$new("keep", default = FALSE, tags = "train"),
+        ParamLgl$new("parallel", default = FALSE, tags = "train"),
+        ParamInt$new("trace.it", default = 0, lower = 0, upper = 1, tags = "train"),
+        ParamFct$new("alignment",
+          default = "lambda",
+          levels = c("lambda", "fraction"), tags = "train"),
+        ParamLgl$new("grouped", default = TRUE, tags = "train"),
+        ParamUty$new("offset", default = NULL, tags = "train"),
         ParamLgl$new("relax", default = FALSE, tags = "train"),
         ParamDbl$new("fdev", default = 1.0e-5, lower = 0, upper = 1, tags = "train"),
         ParamDbl$new("devmax", default = 0.999, lower = 0, upper = 1, tags = "train"),
@@ -55,7 +70,10 @@ LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet", inherit = LearnerClassif,
         ParamDbl$new("pmin", default = 1.0e-9, lower = 0, upper = 1, tags = "train"),
         ParamDbl$new("exmx", default = 250.0, tags = "train"),
         ParamDbl$new("prec", default = 1e-10, tags = "train"),
-        ParamInt$new("mxit", default = 100L, lower = 1L, tags = "train")
+        ParamInt$new("mxit", default = 100L, lower = 1L, tags = "train"),
+        ParamUty$new("newoffset", tags = "predict"),
+        ParamLgl$new("exact", default = FALSE, tags = "predict"),
+        ParamDbl$new("gamma", default = 1, tags = "predict")
       ))
       ps$add_dep("gamma", "relax", CondEqual$new(TRUE))
 
@@ -68,9 +86,11 @@ LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet", inherit = LearnerClassif,
         packages = "glmnet",
         man = "mlr3learners::mlr_learners_classif.glmnet"
       )
-    },
+    }
+  ),
 
-    train_internal = function(task) {
+  private = list(
+    .train = function(task) {
 
       pars = self$param_set$get_values(tags = "train")
       data = as.matrix(task$data(cols = task$feature_names))
@@ -81,27 +101,36 @@ LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet", inherit = LearnerClassif,
       pars$family = ifelse(length(task$class_names) == 2L, "binomial", "multinomial")
 
       saved_ctrl = glmnet::glmnet.control()
-      on.exit(invoke(glmnet::glmnet.control, .args = saved_ctrl))
+      on.exit(mlr3misc::invoke(glmnet::glmnet.control, .args = saved_ctrl))
       glmnet::glmnet.control(factory = TRUE)
       is_ctrl_pars = names(pars) %in% names(saved_ctrl)
 
       if (any(is_ctrl_pars)) {
-        do.call(glmnet::glmnet.control, pars[is_ctrl_pars])
+        mlr3misc::invoke(glmnet::glmnet.control, .args = pars[is_ctrl_pars])
         pars = pars[!is_ctrl_pars]
       }
 
-      invoke(glmnet::cv.glmnet, x = data, y = target, .args = pars)
+      mlr3misc::invoke(glmnet::glmnet, x = data, y = target, .args = pars)
     },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
       pars = self$param_set$get_values(tags = "predict")
       newdata = as.matrix(task$data(cols = task$feature_names))
 
+      # only predict for one instance of 's' and not for 100
+      if (is.null(pars$s)) {
+        pars$s = self$param_set$default$s
+      }
+
       if (self$predict_type == "response") {
-        response = invoke(predict, self$model, newx = newdata, type = "class", .args = pars)
+        response = mlr3misc::invoke(predict, self$model,
+          newx = newdata, type = "class",
+          .args = pars)
         PredictionClassif$new(task = task, response = drop(response))
       } else {
-        prob = invoke(predict, self$model, newx = newdata, type = "response", .args = pars)
+        prob = mlr3misc::invoke(predict, self$model,
+          newx = newdata, type = "response",
+          .args = pars)
 
         if (length(task$class_names) == 2L) {
           prob = cbind(prob, 1 - prob)
