@@ -1,39 +1,46 @@
 #' @title GLM with Elastic Net Regularization Regression Learner
 #'
-#' @usage NULL
 #' @name mlr_learners_regr.glmnet
-#' @format [R6::R6Class()] inheriting from [mlr3::LearnerRegr].
-#'
-#' @section Construction:
-#' ```
-#' LearnerRegrGlmnet$new()
-#' mlr3::mlr_learners$get("regr.glmnet")
-#' mlr3::lrn("regr.glmnet")
-#' ```
 #'
 #' @description
 #' Generalized linear models with elastic net regularization.
-#' Calls [glmnet::cv.glmnet()] from package \CRANpkg{glmnet}.
+#' Calls [glmnet::glmnet()] from package \CRANpkg{glmnet}.
 #'
 #' The default for hyperparameter `family` is changed to `"gaussian"`.
 #'
+#' Caution: This learner is different to `cv_glmnet` in that it does not use the
+#' internal optimization of lambda. The parameter needs to be tuned by the user.
+#' Essentially, one needs to tune parameter `s` which is used at predict-time.
+#'
+#' See https://stackoverflow.com/questions/50995525/ for more information.
+#'
+#' @templateVar id regr.glmnet
+#' @template section_dictionary_learner
+#'
 #' @references
 #' \cite{mlr3learners}{friedman_2010}
 #'
 #' @export
 #' @template seealso_learner
-#' @templateVar learner_name regr.glmnet
 #' @template example
-LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet", inherit = LearnerRegr,
+LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet",
+  inherit = LearnerRegr,
+
   public = list(
+
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       ps = ParamSet$new(list(
-        ParamFct$new("family", default = "gaussian", levels = c("gaussian", "poisson"), tags = "train"),
+        ParamFct$new("family",
+          default = "gaussian", levels = c("gaussian", "poisson"),
+          tags = "train"),
         ParamUty$new("offset", default = NULL, tags = "train"),
         ParamDbl$new("alpha", default = 1, lower = 0, upper = 1, tags = "train"),
-        ParamInt$new("nfolds", lower = 3L, default = 10L, tags = "train"),
-        ParamFct$new("type.measure", levels = c("deviance", "class", "auc", "mse", "mae"), default = "deviance", tags = "train"),
-        ParamDbl$new("s", lower = 0, special_vals = list("lambda.1se", "lambda.min"), default = "lambda.1se", tags = "predict"),
+        ParamFct$new("type.measure",
+          levels = c("deviance", "class", "auc", "mse", "mae"),
+          default = "deviance", tags = "train"),
+        ParamDbl$new("s", lower = 0, default = 0.01, tags = "predict"),
         ParamInt$new("nlambda", default = 100L, lower = 1L, tags = "train"),
         ParamDbl$new("lambda.min.ratio", lower = 0, upper = 1, tags = "train"),
         ParamUty$new("lambda", tags = "train"),
@@ -50,7 +57,13 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet", inherit = LearnerRegr,
         ParamFct$new("type.gaussian", levels = c("covariance", "naive"), tags = "train"),
         ParamFct$new("type.logistic", levels = c("Newton", "modified.Newton"), tags = "train"),
         ParamFct$new("type.multinomial", levels = c("ungrouped", "grouped"), tags = "train"),
-        ParamUty$new("gamma", tags = "train"),
+        ParamLgl$new("keep", default = FALSE, tags = "train"),
+        ParamLgl$new("parallel", default = FALSE, tags = "train"),
+        ParamInt$new("trace.it", default = 0, lower = 0, upper = 1, tags = "train"),
+        ParamFct$new("alignment",
+          default = "lambda",
+          levels = c("lambda", "fraction"), tags = "train"),
+        ParamLgl$new("grouped", default = TRUE, tags = "train"),
         ParamLgl$new("relax", default = FALSE, tags = "train"),
         ParamDbl$new("fdev", default = 1.0e-5, lower = 0, upper = 1, tags = "train"),
         ParamDbl$new("devmax", default = 0.999, lower = 0, upper = 1, tags = "train"),
@@ -60,7 +73,11 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet", inherit = LearnerRegr,
         ParamDbl$new("pmin", default = 1.0e-9, lower = 0, upper = 1, tags = "train"),
         ParamDbl$new("exmx", default = 250.0, tags = "train"),
         ParamDbl$new("prec", default = 1e-10, tags = "train"),
-        ParamInt$new("mxit", default = 100L, lower = 1L, tags = "train")
+        ParamInt$new("mxit", default = 100L, lower = 1L, tags = "train"),
+        ParamUty$new("newoffset", tags = "predict"),
+        ParamDbl$new("predict.gamma", default = 1, tags = "predict"),
+        ParamLgl$new("exact", default = FALSE, tags = "predict"),
+        ParamDbl$new("gamma", default = 1, tags = "predict")
       ))
       ps$add_dep("gamma", "relax", CondEqual$new(TRUE))
       ps$add_dep("type.gaussian", "family", CondEqual$new("gaussian"))
@@ -75,9 +92,11 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet", inherit = LearnerRegr,
         packages = "glmnet",
         man = "mlr3learners::mlr_learners_regr.glmnet"
       )
-    },
+    }
+  ),
 
-    train_internal = function(task) {
+  private = list(
+    .train = function(task) {
 
       pars = self$param_set$get_values(tags = "train")
       data = as.matrix(task$data(cols = task$feature_names))
@@ -87,23 +106,30 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet", inherit = LearnerRegr,
       }
 
       saved_ctrl = glmnet::glmnet.control()
-      on.exit(invoke(glmnet::glmnet.control, .args = saved_ctrl))
+      on.exit(mlr3misc::invoke(glmnet::glmnet.control, .args = saved_ctrl))
       glmnet::glmnet.control(factory = TRUE)
       is_ctrl_pars = (names(pars) %in% names(saved_ctrl))
 
       if (any(is_ctrl_pars)) {
-        do.call(glmnet::glmnet.control, pars[is_ctrl_pars])
+        mlr3misc::invoke(glmnet::glmnet.control, .args = pars[is_ctrl_pars])
         pars = pars[!is_ctrl_pars]
       }
 
-      invoke(glmnet::cv.glmnet, x = data, y = target, .args = pars)
+      mlr3misc::invoke(glmnet::glmnet, x = data, y = target, .args = pars)
     },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
       pars = self$param_set$get_values(tags = "predict")
       newdata = as.matrix(task$data(cols = task$feature_names))
 
-      response = invoke(predict, self$model, newx = newdata, type = "response", .args = pars)
+      # only predict for one instance of 's' and not for 100
+      if (is.null(pars$s)) {
+        pars$s = self$param_set$default$s
+      }
+
+      response = mlr3misc::invoke(predict, self$model,
+        newx = newdata,
+        type = "response", .args = pars)
       PredictionRegr$new(task = task, response = drop(response))
     }
   )
