@@ -1,20 +1,14 @@
 #' @title k-Nearest-Neighbor Regression Learner
 #'
-#' @usage NULL
 #' @name mlr_learners_regr.kknn
-#' @format [R6::R6Class()] inheriting from [mlr3::LearnerRegr].
-#'
-#' @section Construction:
-#' ```
-#' LearnerRegrKKNN$new()
-#' mlr3::mlr_learners$get("regr.kknn")
-#' mlr3::lrn("regr.kknn")
-#' ```
 #'
 #' @description
 #' k-Nearest-Neighbor regression.
 #' Calls [kknn::kknn()] from package \CRANpkg{kknn}.
 #'
+#' @templateVar id regr.kknn
+#' @template section_dictionary_learner
+#'
 #' @references
 #' \cite{mlr3learners}{hechenbichler_2004}
 #'
@@ -24,16 +18,24 @@
 #'
 #' @export
 #' @template seealso_learner
-#' @templateVar learner_name regr.kknn
 #' @template example
-LearnerRegrKKNN = R6Class("LearnerRegrKKNN", inherit = LearnerRegr,
+LearnerRegrKKNN = R6Class("LearnerRegrKKNN",
+  inherit = LearnerRegr,
   public = list(
+
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       ps = ParamSet$new(list(
         ParamInt$new("k", default = 7L, lower = 1L, tags = "train"),
         ParamDbl$new("distance", default = 2, lower = 0, tags = "train"),
-        ParamFct$new("kernel", levels = c("rectangular", "triangular", "epanechnikov", "biweight", "triweight", "cos", "inv", "gaussian", "rank", "optimal"), default = "optimal", tags = "train"),
-        ParamLgl$new("scale", default = TRUE, tags = "train")
+        ParamFct$new("kernel",
+          levels = c(
+            "rectangular", "triangular", "epanechnikov", "biweight",
+            "triweight", "cos", "inv", "gaussian", "rank", "optimal"),
+          default = "optimal", tags = "train"),
+        ParamLgl$new("scale", default = TRUE, tags = "train"),
+        ParamUty$new("ykernel", default = NULL, tags = "train")
       ))
 
       super$initialize(
@@ -43,9 +45,11 @@ LearnerRegrKKNN = R6Class("LearnerRegrKKNN", inherit = LearnerRegr,
         packages = "kknn",
         man = "mlr3learners::mlr_learners_regr.kknn"
       )
-    },
+    }
+  ),
 
-    train_internal = function(task) {
+  private = list(
+    .train = function(task) {
       list(
         formula = task$formula(),
         data = task$data(),
@@ -53,15 +57,17 @@ LearnerRegrKKNN = R6Class("LearnerRegrKKNN", inherit = LearnerRegr,
       )
     },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
       model = self$model
       newdata = task$data(cols = task$feature_names)
 
       with_package("kknn", { # https://github.com/KlausVigo/kknn/issues/16
-        p = invoke(kknn::kknn, formula = model$formula, train = model$data, test = newdata, .args = model$pars)
+        pred = invoke(kknn::kknn,
+          formula = model$formula, train = model$data,
+          test = newdata, .args = model$pars)
       })
 
-      PredictionRegr$new(task = task, response = p$fitted.values)
+      PredictionRegr$new(task = task, response = pred$fitted.values)
     }
   )
 )
