@@ -1,37 +1,40 @@
 #' @title Kriging Regression Learner
 #'
-#' @usage NULL
 #' @name mlr_learners_regr.km
-#' @format [R6::R6Class()] inheriting from [mlr3::LearnerRegr].
-#'
-#' @section Construction:
-#' ```
-#' LearnerRegrKM$new()
-#' mlr3::mlr_learners$get("regr.km")
-#' mlr3::lrn("regr.km")
-#' ```
 #'
 #' @description
 #' Kriging regression.
 #' Calls [DiceKriging::km()] from package \CRANpkg{DiceKriging}.
 #'
-#' * The predict type hyperparameter "type" defaults to "SK" (simple Kriging).
-#' * The additional hyperparameter `nugget.stability` is used to overwrite the hyperparameter `nugget` with `nugget.stability * var(y)` before training to improve the numerical stability.
-#'   We recommend a value of `1e-8`.
-#' * The additional hyperparameter `jitter` can be set to add `N(0, [jitter])`-distributed noise to the data before prediction to avoid perfect interpolation. We recommend a value of `1e-12`.
+#' * The predict type hyperparameter "type" defaults to "sk" (simple kriging).
+#' * The additional hyperparameter `nugget.stability` is used to overwrite the
+#'   hyperparameter `nugget` with `nugget.stability * var(y)` before training to
+#'   improve the numerical stability. We recommend a value of `1e-8`.
+#' * The additional hyperparameter `jitter` can be set to add `N(0,
+#'   [jitter])`-distributed noise to the data before prediction to avoid perfect
+#'   interpolation. We recommend a value of `1e-12`.
+#'
+#' @template section_dictionary_learner
+#' @templateVar id regr.km
 #'
 #' @references
 #' \cite{mlr3learners}{roustant_2012}
 #'
 #' @export
 #' @template seealso_learner
-#' @templateVar learner_name regr.km
 #' @template example
-LearnerRegrKM = R6Class("LearnerRegrKM", inherit = LearnerRegr,
+LearnerRegrKM = R6Class("LearnerRegrKM",
+  inherit = LearnerRegr,
+
   public = list(
+
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       ps = ParamSet$new(list(
-        ParamFct$new("covtype", default = "matern5_2", levels = c("gauss", "matern5_2", "matern3_2", "exp", "powexp"), tags = "train"),
+        ParamFct$new("covtype",
+          default = "matern5_2",
+          levels = c("gauss", "matern5_2", "matern3_2", "exp", "powexp"), tags = "train"),
         ParamUty$new("coef.trend", default = NULL, tags = "train"),
         ParamUty$new("coef.cov", default = NULL, tags = "train"),
         ParamUty$new("coef.var", default = NULL, tags = "train"),
@@ -52,7 +55,13 @@ LearnerRegrKM = R6Class("LearnerRegrKM", inherit = LearnerRegr,
         ParamUty$new("knots", default = NULL, tags = "train"),
         ParamUty$new("kernel", default = NULL, tags = "train"),
         ParamFct$new("type", default = "SK", levels = c("SK", "UK"), tags = "predict"),
-        ParamDbl$new("jitter", default = 0, lower = 0, tags = "predict")
+        ParamDbl$new("jitter", default = 0, lower = 0, tags = "predict"),
+        ParamUty$new("control", default = NULL, tags = "train"),
+        ParamLgl$new("se.compute", default = TRUE, tags = "predict"),
+        ParamLgl$new("cov.compute", default = TRUE, tags = "predict"),
+        ParamLgl$new("light.return", default = FALSE, tags = "predict"),
+        ParamLgl$new("bias.correct", default = FALSE, tags = "predict"),
+        ParamLgl$new("checkNames", default = TRUE, tags = "predict")
       ))
       ps$add_dep("multistart", "optim.method", CondEqual$new("BFGS"))
       ps$add_dep("knots", "scaling", CondEqual$new(TRUE))
@@ -65,9 +74,11 @@ LearnerRegrKM = R6Class("LearnerRegrKM", inherit = LearnerRegr,
         packages = "DiceKriging",
         man = "mlr3learners::mlr_learners_regr.km"
       )
-    },
+    }
+  ),
 
-    train_internal = function(task) {
+  private = list(
+    .train = function(task) {
 
       pars = self$param_set$get_values(tags = "train")
       data = as.matrix(task$data(cols = task$feature_names))
@@ -84,15 +95,15 @@ LearnerRegrKM = R6Class("LearnerRegrKM", inherit = LearnerRegr,
         pars$nugget = if (ns == 0) 0 else ns * var(truth)
       }
 
-      invoke(DiceKriging::km,
+      mlr3misc::invoke(DiceKriging::km,
         response = task$truth(),
         design = data,
-        control = list(trace = FALSE),
+        control = pars$control,
         .args = remove_named(pars, "nugget.stability")
       )
     },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
       pars = self$param_set$get_values(tags = "predict")
       newdata = as.matrix(task$data(cols = task$feature_names))
 
@@ -101,7 +112,7 @@ LearnerRegrKM = R6Class("LearnerRegrKM", inherit = LearnerRegr,
         newdata = newdata + rnorm(length(newdata), mean = 0, sd = jitter)
       }
 
-      p = invoke(DiceKriging::predict.km,
+      p = mlr3misc::invoke(DiceKriging::predict.km,
         self$model,
         newdata = newdata,
         type = pars$type %??% "SK",
