@@ -1,20 +1,14 @@
 #' @title Ranger Regression Learner
 #'
-#' @usage NULL
 #' @name mlr_learners_regr.ranger
-#' @format [R6::R6Class()] inheriting from [mlr3::LearnerClassif].
-#'
-#' @section Construction:
-#' ```
-#' LearnerRegrRanger$new()
-#' mlr3::mlr_learners$get("regr.ranger")
-#' mlr3::lrn("regr.ranger")
-#' ```
 #'
 #' @description
 #' Random regression forest.
 #' Calls [ranger::ranger()] from package \CRANpkg{ranger}.
 #'
+#' @templateVar id regr.ranger
+#' @template section_dictionary_learner
+#'
 #' @references
 #' \cite{mlr3learners}{wright_2017}
 #'
@@ -22,34 +16,62 @@
 #'
 #' @export
 #' @template seealso_learner
-#' @templateVar learner_name regr.ranger
 #' @template example
-LearnerRegrRanger = R6Class("LearnerRegrRanger", inherit = LearnerRegr,
+LearnerRegrRanger = R6Class("LearnerRegrRanger",
+  inherit = LearnerRegr,
+
   public = list(
+
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
+
       ps = ParamSet$new(list(
         ParamInt$new("num.trees", default = 500L, lower = 1L, tags = c("train", "predict")),
         ParamInt$new("mtry", lower = 1L, tags = "train"),
-        ParamFct$new("importance", levels = c("none", "impurity", "impurity_corrected", "permutation"), tags = "train"),
+        ParamFct$new("importance",
+          levels = c(
+            "none", "impurity",
+            "impurity_corrected", "permutation"),
+          tags = "train"),
         ParamLgl$new("write.forest", default = TRUE, tags = "train"),
-        ParamInt$new("min.node.size", default = 5L, lower = 1L, tags = "train"), # for probability == TRUE, def = 10
+        ParamInt$new("min.node.size", default = 5L, lower = 1L, tags = "train"),
         ParamLgl$new("replace", default = TRUE, tags = "train"),
-        ParamDbl$new("sample.fraction", lower = 0L, upper = 1L, tags = "train"), # for replace == FALSE, def = 0.632
-        ParamFct$new("splitrule", levels = c("variance", "extratrees", "maxstat"), default = "variance", tags = "train"),
+        ParamDbl$new("sample.fraction", lower = 0L, upper = 1L, tags = "train"),
+        ParamFct$new("splitrule",
+          levels = c("variance", "extratrees", "maxstat"),
+          default = "variance", tags = "train"),
         ParamInt$new("num.random.splits", lower = 1L, default = 1L, tags = "train"),
         ParamDbl$new("alpha", default = 0.5, tags = "train"),
         ParamDbl$new("minprop", default = 0.1, tags = "train"),
         ParamDbl$new("split.select.weights", lower = 0, upper = 1, tags = "train"),
         ParamUty$new("always.split.variables", tags = "train"),
-        ParamFct$new("respect.unordered.factors", levels = c("ignore", "order", "partition"), default = "ignore", tags = "train"), # for splitrule == "extratrees", def = partition
-        ParamLgl$new("scale.permutation.importance", default = FALSE, tags = "train"),
+        ParamFct$new("respect.unordered.factors",
+          levels = c("ignore", "order", "partition"),
+          default = "ignore", tags = "train"),
         ParamLgl$new("keep.inbag", default = FALSE, tags = "train"),
-        ParamLgl$new("holdout", default = FALSE, tags = "train"), # FIXME: do we need this?
+        ParamLgl$new("holdout", default = FALSE, tags = "train"),
         ParamInt$new("num.threads", lower = 1L, tags = c("train", "predict")),
         ParamLgl$new("save.memory", default = FALSE, tags = "train"),
         ParamLgl$new("verbose", default = TRUE, tags = c("train", "predict")),
-        ParamLgl$new("oob.error", default = TRUE, tags = "train")
+        ParamLgl$new("oob.error", default = TRUE, tags = "train"),
+        ParamLgl$new("scale.permutation.importance", default = FALSE, tags = "train"),
+        ParamInt$new("max.depth", default = NULL, special_vals = list(NULL), tags = "train"),
+        ParamDbl$new("min.prop", default = 0.1, tags = "train"),
+        ParamUty$new("regularization.factor", default = 1, tags = "train"),
+        ParamLgl$new("regularization.usedepth", default = FALSE, tags = "train"),
+        ParamInt$new("seed",
+          default = NULL, special_vals = list(NULL),
+          tags = c("train", "predict")),
+        ParamLgl$new("quantreg", default = FALSE, tags = "train"),
+        ParamLgl$new("predict.all", default = FALSE, tags = "predict"),
+        # FIXME: only works if predict_type == "se". How to set dependency?
+        ParamFct$new("se.method",
+          default = "infjack", levels = c("jack", "infjack"),
+          tags = "predict")
       ))
+
+      # deps
       ps$add_dep("num.random.splits", "splitrule", CondEqual$new("extratrees"))
       ps$add_dep("alpha", "splitrule", CondEqual$new("maxstat"))
       ps$add_dep("minprop", "splitrule", CondEqual$new("maxstat"))
@@ -67,28 +89,12 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger", inherit = LearnerRegr,
       )
     },
 
-    train_internal = function(task) {
-      pars = self$param_set$get_values(tags = "train")
-
-      if (self$predict_type == "se") {
-        pars$keep.inbag = TRUE
-      }
-
-      invoke(ranger::ranger,
-        dependent.variable.name = task$target_names,
-        data = task$data(),
-        case.weights = task$weights$weight,
-        .args = pars
-      )
-    },
-
-    predict_internal = function(task) {
-      pars = self$param_set$get_values(tags = "predict")
-      newdata = task$data(cols = task$feature_names)
-      preds = invoke(predict, self$model, data = newdata, type = self$predict_type, .args = pars)
-      PredictionRegr$new(task = task, response = preds$predictions, se = preds$se)
-    },
-
+    #' @description
+    #' The importance scores are extracted from the model slot `variable.importance`.
+    #' Parameter `importance.mode` must be set to `"impurity"`, `"impurity_corrected"`, or
+    #' `"permutation"`
+    #'
+    #' @return Named `numeric()`.
     importance = function() {
       if (is.null(self$model)) {
         stopf("No model stored")
@@ -100,8 +106,38 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger", inherit = LearnerRegr,
       sort(self$model$variable.importance, decreasing = TRUE)
     },
 
+    #' @description
+    #' The out-of-bag error, extracted from model slot `prediction.error`.
+    #'
+    #' @return `numeric(1)`.
     oob_error = function() {
       self$model$prediction.error
     }
+  ),
+
+  private = list(
+    .train = function(task) {
+      pars = self$param_set$get_values(tags = "train")
+
+      if (self$predict_type == "se") {
+        pars$keep.inbag = TRUE # nolint
+      }
+
+      mlr3misc::invoke(ranger::ranger,
+        dependent.variable.name = task$target_names,
+        data = task$data(),
+        case.weights = task$weights$weight,
+        .args = pars
+      )
+    },
+
+    .predict = function(task) {
+      pars = self$param_set$get_values(tags = "predict")
+      newdata = task$data(cols = task$feature_names)
+      preds = mlr3misc::invoke(predict, self$model,
+        data = newdata,
+        type = self$predict_type, .args = pars)
+      PredictionRegr$new(task = task, response = preds$predictions, se = preds$se)
+    }
   )
 )
